;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "faff-theme" "20251120.1400"
  "Light Emacs color theme on cornsilk3 background."
  ()
  :url "https://github.com/WJCFerguson/emacs-faff-theme"
  :commit "e8b6b4b5669fb41f0dd4fdcbcb88b5b9ab803f53"
  :revdesc "e8b6b4b5669f"
  :keywords '("color" "theme")
  :authors '(("James Ferguson" . ""))
  :maintainers '(("James Ferguson" . "")))
